@@ -1,8 +1,7 @@
 from webcompy.elements import html
 from webcompy.components import define_component, ComponentContext
-from webcompy.router import RouterContext
 
 
 @define_component
-def DocumentHome(_: ComponentContext[RouterContext]):
+def DocumentHome(_: ComponentContext[None]):
     return html.DIV({}, "Work In Progress...")
