@@ -1,13 +1,17 @@
-from typing import TypeAlias
+from __future__ import annotations
+from typing import Optional
+from typing_extensions import TypeAlias
 from webcompy.elements.types import Element, RepeatElement
 from webcompy.elements.typealias import ElementChildren
+from webcompy.components._component import Component
 from webcompy.reactive._computed import computed
 from webcompy.app._app import WebComPyApp
 from webcompy.cli._config import WebComPyConfig
+from webcompy.utils import strip_multiline_text
 from webcompy._version import __version__ as webcompy_version
 
 
-Scripts: TypeAlias = list[tuple[dict[str, str], str | None]]
+Scripts: TypeAlias = list[tuple[dict[str, str], Optional[str]]]
 
 
 class _HtmlElement(Element):
@@ -31,8 +35,8 @@ class _HtmlElement(Element):
     def _get_belonging_component(self):
         return ""
 
-    def _get_belonging_components(self):
-        return tuple()
+    def _get_belonging_components(self) -> tuple[Component, ...]:
+        return tuple([])
 
 
 class _Loadscreen(_HtmlElement):
@@ -113,7 +117,7 @@ def _load_scripts(scripts: Scripts):
         _HtmlElement(
             "script",
             attrs,
-            script if script else "",
+            script,
         )
         for attrs, script in scripts
     ]
@@ -138,107 +142,50 @@ def generate_html(
     scripts_head: Scripts = []
     scripts_body: Scripts = []
 
-    if config.environment == "pyscript":
-        scripts_head.append(
-            (
-                {
-                    "type": "text/javascript",
-                    "defer": "",
-                    "src": "https://pyscript.net/alpha/pyscript.js",
-                },
-                None,
-            )
+    scripts_head.append(
+        (
+            {
+                "type": "text/javascript",
+                "defer": "",
+                "src": "https://pyscript.net/alpha/pyscript.js",
+            },
+            None,
         )
-        app_loader.append(
-            _HtmlElement(
-                "py-env",
-                {"hidden": ""},
-                "\n"
-                + "\n".join(
-                    f"- '{p}'" if p.endswith(".whl") else f"- {p}"
-                    for p in [
-                        *config.dependencies,
-                        f"{config.base}webcompy-app-package/webcompy-{webcompy_version}-py3-none-any.whl",
-                        f"{config.base}webcompy-app-package/app-{app_version}-py3-none-any.whl",
-                    ]
-                )
-                + "\n",
-            )
-        )
-        app_loader.append(
-            _HtmlElement(
-                "py-script",
-                {"hidden": ""},
-                "\n"
-                + "\n".join(
-                    (
-                        f"from {config.app_package}.bootstrap import app",
-                        "app.__component__.render()",
-                    )
-                )
-                + "\n",
-            )
-        )
-    else:
-        scripts_body.extend(
-            [
-                (
-                    {
-                        "type": "text/javascript",
-                        "src": f"{config.base}webcompy-app-package/brython.js",
-                    },
-                    None,
-                ),
-                (
-                    {
-                        "type": "text/javascript",
-                        "src": f"{config.base}webcompy-app-package/brython_stdlib.js",
-                    },
-                    None,
-                ),
-                (
-                    {
-                        "type": "text/javascript",
-                        "src": f"{config.base}webcompy-app-package/webcompy.brython.js",
-                    },
-                    None,
-                ),
-                (
-                    {
-                        "type": "text/javascript",
-                        "src": f"{config.base}webcompy-app-package/{config.app_package}.brython.js",
-                    },
-                    None,
-                ),
-            ]
-        )
-        app_loader.extend(
-            _load_scripts(
-                [
-                    (
-                        {"type": "text/python"},
-                        "\n"
-                        + "\n".join(
-                            (
-                                f"from {config.app_package}.bootstrap import app",
-                                "app.__component__.render()",
-                            )
+    )
+    app_loader.append(
+        _HtmlElement(
+            "py-script",
+            {},
+            "\n"
+            + strip_multiline_text(
+                """
+                import micropip, pyodide, js
+                from traceback import TracebackException
+                async def bootstarp():
+                    try:
+                        await micropip.install([{dependencies}])
+                        from {app_package_name}.bootstrap import app
+                        app.__component__.render()
+                    except Exception as err:
+                        js.console.error("".join(TracebackException.from_exception(err).format()))
+                try:
+                    pyodide.webloop.WebLoop().run_until_complete(bootstarp())
+                except Exception as err:
+                    js.console.error("".join(TracebackException.from_exception(err).format()))
+                """.format(
+                    app_package_name=config.app_package,
+                    dependencies=",".join(
+                        '"' + p + '"'
+                        for p in (
+                            *{*config.dependencies, "typing_extensions"},
+                            f"{config.base}_webcompy-app-package/webcompy-{webcompy_version}-py3-none-any.whl",
+                            f"{config.base}_webcompy-app-package/app-{app_version}-py3-none-any.whl",
                         )
-                        + "\n",
                     ),
-                    (
-                        {"type": "text/javascript"},
-                        "brython({{{brython_options}}});".format(
-                            brython_options=(
-                                "debug: 1, cache: false, indexedDB: true"
-                                if dev_mode
-                                else "debug: 0, cache: true, indexedDB: true"
-                            )
-                        ),
-                    ),
-                ]
-            )
+                )
+            ),
         )
+    )
 
     scripts_head.extend(app.__component__.head["script"])
     scripts_body.extend(app.__component__.scripts)
@@ -274,7 +221,13 @@ def generate_html(
                 _HtmlElement(
                     "style",
                     {},
-                    " ".join(("*[hidden]{display: none;}", app.__component__.style)),
+                    " ".join(
+                        (
+                            "*[hidden]{display: none;}",
+                            "py-script, py-config, py-loader {display: none;}",
+                            app.__component__.style,
+                        )
+                    ),
                 ),
                 *[
                     _HtmlElement("link", attrs)
