@@ -5,6 +5,7 @@ from re import compile as re_compile, escape as re_escape
 import mimetypes
 import pathlib
 from tempfile import TemporaryDirectory
+import aiofiles
 from starlette.applications import Starlette
 from starlette.requests import Request
 from starlette.responses import HTMLResponse, Response
@@ -15,8 +16,7 @@ from sse_starlette.sse import EventSourceResponse
 import uvicorn  # type: ignore
 from webcompy.app._app import WebComPyApp
 from webcompy.cli._argparser import get_params
-from webcompy.cli._pyscript_wheel import make_webcompy_app_package_pyscript
-from webcompy.cli._brython_cli import make_webcompy_app_package_brython
+from webcompy.cli._pyscript_wheel import make_webcompy_app_package
 from webcompy.cli._config import WebComPyConfig
 from webcompy.cli._html import generate_html
 from webcompy.cli._utils import (
@@ -24,6 +24,7 @@ from webcompy.cli._utils import (
     get_webcompy_packge_dir,
     generate_app_version,
 )
+from webcompy.cli._static_files import get_static_files
 
 
 def create_asgi_app(
@@ -31,13 +32,9 @@ def create_asgi_app(
 ) -> ASGIApp:
     app_version = generate_app_version()
 
+    # App Packages
     with TemporaryDirectory() as temp:
         temp_path = pathlib.Path(temp)
-        make_webcompy_app_package = (
-            make_webcompy_app_package_pyscript
-            if config.environment == "pyscript"
-            else make_webcompy_app_package_brython
-        )
         make_webcompy_app_package(
             temp_path,
             get_webcompy_packge_dir(),
@@ -47,7 +44,9 @@ def create_asgi_app(
         app_package_files: dict[str, tuple[bytes, str]] = {
             p.name: (
                 p.open("rb").read(),
-                t if (t := mimetypes.guess_type(p)[0]) else "application/octet-stream",
+                t
+                if (t := mimetypes.guess_type(str(p))[0])
+                else "application/octet-stream",
             )
             for p in temp_path.iterdir()
         }
@@ -59,7 +58,28 @@ def create_asgi_app(
             return Response(content, media_type=media_type)
         else:
             raise HTTPException(404)
+    
+    app_package_files_route = Route(
+        config.base + "_webcompy-app-package/{filename:path}",
+        send_app_package_file,
+    )
 
+    # Static Files
+    static_file_routes: list[Route] = []
+    static_files_dir = pathlib.Path(f"./{config.static_files_dir}").absolute()
+    for relative_path in get_static_files(static_files_dir):
+        static_file = static_files_dir / relative_path
+        if (media_type := mimetypes.guess_type(str(static_file))[0]) is None:
+            media_type = "application/octet-stream"
+
+        async def send_file(request: Request):
+            async with aiofiles.open(static_file, "rb") as f:
+                content = await f.read()
+            return Response(content, media_type=media_type)
+
+        static_file_routes.append(Route(config.base + relative_path, send_file))
+
+    # HTMLs
     html_generator = partial(generate_html, config, dev_mode, True, app_version)
     base_url_stripper = partial(
         re_compile("^" + re_escape("/" + config.base.strip("/"))).sub,
@@ -67,7 +87,6 @@ def create_asgi_app(
     )
 
     if app.__component__.router_mode == "history" and app.__component__.routes:
-        html_route = config.base + "{path:path}"
 
         async def send_html(request: Request):  # type: ignore
             # get requested path
@@ -85,22 +104,17 @@ def create_asgi_app(
             else:
                 raise HTTPException(404)
 
+        html_route = Route(config.base + "{path:path}", send_html)
     else:
-        html_route = config.base
         app.__component__.set_path("/")
         html = html_generator(app)
 
         async def send_html(_: Request):  # type: ignore
             return HTMLResponse(html)
 
-    routes = [
-        Route(
-            config.base + "webcompy-app-package/{filename:path}",
-            send_app_package_file,
-        ),
-        Route(html_route, send_html),
-    ]
+        html_route = Route(config.base, send_html)
 
+    # Hot Reloader
     if dev_mode:
 
         async def loop():
@@ -111,9 +125,19 @@ def create_asgi_app(
         async def sse(_: Request):
             return EventSourceResponse(loop())
 
-        routes.insert(0, Route(f"{config.base}_webcompy_reload", endpoint=sse))
+        dev_routes = [Route(f"{config.base}_webcompy_reload", endpoint=sse)]
+    else:
+        dev_routes: list[Route] = []
 
-    return Starlette(routes=routes)
+    # Declare ASGI App
+    return Starlette(
+        routes=[
+            *dev_routes,
+            app_package_files_route,
+            *static_file_routes,
+            html_route,
+        ]
+    )
 
 
 def run_server():
