@@ -1,4 +1,4 @@
-from typing import Dict, TypeVar
+from typing import Any, Dict, TypeVar
 from webcompy.reactive._base import Reactive, ReactiveBase
 
 
@@ -18,6 +18,14 @@ class ReactiveDict(Reactive[Dict[K, V]]):
     def __setitem__(self, key: K, value: V):
         self._value.__setitem__(key, value)
 
+    @ReactiveBase._change_event
+    def __delitem__(self, key: K):
+        self._value.__delitem__(key)
+
+    @ReactiveBase._change_event
+    def pop(self, key: K):
+        return self._value.pop(key)
+
     @ReactiveBase._get_evnet
     def __len__(self):
         return len(self._value)
@@ -26,11 +34,18 @@ class ReactiveDict(Reactive[Dict[K, V]]):
     def __iter__(self):
         return iter(self._value)
 
+    @ReactiveBase._get_evnet
+    def get(self, key: K, default: Any = None):
+        return self._value.get(key, default)
+
+    @ReactiveBase._get_evnet
     def keys(self):
         return self._value.keys()
 
+    @ReactiveBase._get_evnet
     def values(self):
         return self._value.values()
 
+    @ReactiveBase._get_evnet
     def items(self):
         return self._value.items()
